@@ -18,6 +18,9 @@ from torch.utils.data import Dataset
 from s3prl_vc.transform.spectrogram import logmelfilterbank
 from s3prl_vc.utils import find_files, get_basename
 
+##########################
+# Datasets with audio #
+##########################
 
 class AudioSCPMelDataset(Dataset):
     """PyTorch compatible audio dataset based on kaldi-stype scp files."""
@@ -252,3 +255,83 @@ class AudioMelDataset(Dataset):
         """
         return len(self.utt_ids)
 
+##########################
+# Datasets without audio #
+##########################
+
+class FeatDataset(Dataset):
+    """PyTorch compatible dataset given a directory of feature files."""
+
+    def __init__(
+        self,
+        featdir,
+        config,
+        query,
+        load_fn,
+        return_utt_id=False,
+        return_sampling_rate=False,
+        allow_cache=False,
+    ):
+        """Initialize dataset.
+
+        Args:
+            wavdir (str): directory of wav files.
+            segments (str): Kaldi-style segments file.
+            return_utt_id (bool): Whether to return utterance id.
+            return_sampling_rate (bool): Wheter to return sampling rate.
+            allow_cache (bool): Whether to allow cache of the loaded files.
+
+        """
+        self.config = config
+        self.load_fn = load_fn
+
+        # find files 
+        self.feat_files = sorted(find_files(featdir, query=query))
+        self.utt_ids = [get_basename(path) for path in self.feat_files]
+
+        self.return_utt_id = return_utt_id
+        self.return_sampling_rate = return_sampling_rate
+        self.allow_cache = allow_cache
+
+        if allow_cache:
+            # NOTE(kan-bayashi): Manager is need to share memory in dataloader with num_workers > 0
+            self.manager = Manager()
+            self.caches = self.manager.list()
+            self.caches += [() for _ in range(len(self.utt_ids))]
+
+    def __getitem__(self, idx):
+        """Get specified idx items.
+
+        Args:
+            idx (int): Index of the item.
+
+        Returns:
+            str: Utterance id (only in return_utt_id = True).
+            ndarray or tuple: Audio signal (T,) or (w/ sampling rate if return_sampling_rate = True).
+
+        """
+        if self.allow_cache and len(self.caches[idx]) != 0:
+            return self.caches[idx]
+
+        utt_id = self.utt_ids[idx]
+        feats = self.load_fn(self.feat_files[idx])
+
+        if self.return_utt_id:
+            items = utt_id, feats
+        else:
+            items = feats
+
+        if self.allow_cache:
+            self.caches[idx] = items
+
+        return items
+
+    def __len__(self):
+        """Return dataset length.
+
+        Returns:
+            int: The length of dataset.
+
+        """
+        return len(self.utt_ids)
+
